package com.ruoyi.adjust.service;

import java.util.List;

import com.ruoyi.adjust.domain.AsynchExpLog;

/**
 * 导步导出日志Service接口
 * 
 * @author klbc
 * @date 2022-05-22
 */
public interface IAsynchExpLogService 
{
    /**
     * 查询导步导出日志
     * 
     * @param id 导步导出日志主键
     * @return 导步导出日志
     */
    public AsynchExpLog selectAsynchExpLogById(Long id);

    /**
     * 查询导步导出日志列表
     * 
     * @param asynchExpLog 导步导出日志
     * @return 导步导出日志集合
     */
    public List<AsynchExpLog> selectAsynchExpLogList(AsynchExpLog asynchExpLog);

    /**
     * 新增导步导出日志
     * 
     * @param asynchExpLog 导步导出日志
     * @return 结果
     */
    public int insertAsynchExpLog(AsynchExpLog asynchExpLog);

    /**
     * 修改导步导出日志
     * 
     * @param asynchExpLog 导步导出日志
     * @return 结果
     */
    public int updateAsynchExpLog(AsynchExpLog asynchExpLog);

    /**
     * 批量删除导步导出日志
     * 
     * @param ids 需要删除的导步导出日志主键集合
     * @return 结果
     */
    public int deleteAsynchExpLogByIds(Long[] ids);

    /**
     * 删除导步导出日志信息
     * 
     * @param id 导步导出日志主键
     * @return 结果
     */
    public int deleteAsynchExpLogById(Long id);
}
